Class: Aws::IoTEvents::Types::AlarmRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEvents::Types::AlarmRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotevents/types.rb
Overview
Note:
When making an API call, you may pass AlarmRule data as a hash:
{
simple_rule: {
input_property: "InputProperty", # required
comparison_operator: "GREATER", # required, accepts GREATER, GREATER_OR_EQUAL, LESS, LESS_OR_EQUAL, EQUAL, NOT_EQUAL
threshold: "Threshold", # required
},
}
Defines when your alarm is invoked.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#simple_rule ⇒ Types::SimpleRule
A rule that compares an input property value to a threshold value with a comparison operator.
Instance Attribute Details
#simple_rule ⇒ Types::SimpleRule
A rule that compares an input property value to a threshold value with a comparison operator.
849 850 851 852 853 |
# File 'lib/aws-sdk-iotevents/types.rb', line 849 class AlarmRule < Struct.new( :simple_rule) SENSITIVE = [] include Aws::Structure end |