Class: Aws::IoTEvents::Types::AssetPropertyVariant

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotevents/types.rb

Overview

A structure that contains an asset property value. For more information, see [Variant] in the *AWS IoT SiteWise API Reference*.

You must use expressions for all parameters in `AssetPropertyVariant`. The expressions accept literals, operators, functions, references, and substitution templates.

*Examples*

  • For literal values, the expressions must contain single quotes. For example, the value for the `integerValue` parameter can be `'100'`.

  • For references, you must specify either variables or parameters. For example, the value for the `booleanValue` parameter can be `$variable.offline`.

  • For a substitution template, you must use `${}`, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.

    In the following example, the value for the `doubleValue` parameter uses a substitution template.

    `'$* 6 / 5 + 32'`

For more information, see [Expressions] in the *AWS IoT Events Developer Guide*.

You must specify one of the following value types, depending on the `dataType` of the specified asset property. For more information, see

AssetProperty][3

in the *AWS IoT SiteWise API Reference*.

[1]: docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_Variant.html [2]: docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html [3]: docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_AssetProperty.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#boolean_valueString

The asset property value is a Boolean value that must be `'TRUE'` or `'FALSE'`. You must use an expression, and the evaluated result should be a Boolean value.

Returns:

  • (String)


731
732
733
734
735
736
737
738
# File 'lib/aws-sdk-iotevents/types.rb', line 731

class AssetPropertyVariant < Struct.new(
  :string_value,
  :integer_value,
  :double_value,
  :boolean_value)
  SENSITIVE = []
  include Aws::Structure
end

#double_valueString

The asset property value is a double. You must use an expression, and the evaluated result should be a double.

Returns:

  • (String)


731
732
733
734
735
736
737
738
# File 'lib/aws-sdk-iotevents/types.rb', line 731

class AssetPropertyVariant < Struct.new(
  :string_value,
  :integer_value,
  :double_value,
  :boolean_value)
  SENSITIVE = []
  include Aws::Structure
end

#integer_valueString

The asset property value is an integer. You must use an expression, and the evaluated result should be an integer.

Returns:

  • (String)


731
732
733
734
735
736
737
738
# File 'lib/aws-sdk-iotevents/types.rb', line 731

class AssetPropertyVariant < Struct.new(
  :string_value,
  :integer_value,
  :double_value,
  :boolean_value)
  SENSITIVE = []
  include Aws::Structure
end

#string_valueString

The asset property value is a string. You must use an expression, and the evaluated result should be a string.

Returns:

  • (String)


731
732
733
734
735
736
737
738
# File 'lib/aws-sdk-iotevents/types.rb', line 731

class AssetPropertyVariant < Struct.new(
  :string_value,
  :integer_value,
  :double_value,
  :boolean_value)
  SENSITIVE = []
  include Aws::Structure
end