Class: Aws::IoTEvents::Types::DescribeAlarmModelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEvents::Types::DescribeAlarmModelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotevents/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_capabilities ⇒ Types::AlarmCapabilities
Contains the configuration information of alarm state changes.
-
#alarm_event_actions ⇒ Types::AlarmEventActions
Contains information about one or more alarm actions.
-
#alarm_model_arn ⇒ String
The ARN of the alarm model.
-
#alarm_model_description ⇒ String
The description of the alarm model.
-
#alarm_model_name ⇒ String
The name of the alarm model.
-
#alarm_model_version ⇒ String
The version of the alarm model.
-
#alarm_notification ⇒ Types::AlarmNotification
Contains information about one or more notification actions.
-
#alarm_rule ⇒ Types::AlarmRule
Defines when your alarm is invoked.
-
#creation_time ⇒ Time
The time the alarm model was created, in the Unix epoch format.
-
#key ⇒ String
An input attribute used as a key to create an alarm.
-
#last_update_time ⇒ Time
The time the alarm model was last updated, in the Unix epoch format.
-
#role_arn ⇒ String
The ARN of the IAM role that allows the alarm to perform actions and access AWS resources.
-
#severity ⇒ Integer
A non-negative integer that reflects the severity level of the alarm.
-
#status ⇒ String
The status of the alarm model.
-
#status_message ⇒ String
Contains information about the status of the alarm model.
Instance Attribute Details
#alarm_capabilities ⇒ Types::AlarmCapabilities
Contains the configuration information of alarm state changes.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_event_actions ⇒ Types::AlarmEventActions
Contains information about one or more alarm actions.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_model_arn ⇒ String
The ARN of the alarm model. For more information, see [Amazon Resource Names (ARNs)] in the *AWS General Reference*.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_model_description ⇒ String
The description of the alarm model.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_model_name ⇒ String
The name of the alarm model.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_model_version ⇒ String
The version of the alarm model.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_notification ⇒ Types::AlarmNotification
Contains information about one or more notification actions.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_rule ⇒ Types::AlarmRule
Defines when your alarm is invoked.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The time the alarm model was created, in the Unix epoch format.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
An input attribute used as a key to create an alarm. AWS IoT Events routes [inputs] associated with this key to the alarm.
[1]: docs.aws.amazon.com/iotevents/latest/apireference/API_Input.html
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#last_update_time ⇒ Time
The time the alarm model was last updated, in the Unix epoch format.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that allows the alarm to perform actions and access AWS resources. For more information, see [Amazon Resource Names (ARNs)] in the *AWS General Reference*.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ Integer
A non-negative integer that reflects the severity level of the alarm.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the alarm model. The status can be one of the following values:
-
`ACTIVE` - The alarm model is active and it's ready to evaluate data.
-
`ACTIVATING` - AWS IoT Events is activating your alarm model. Activating an alarm model can take up to a few minutes.
-
`INACTIVE` - The alarm model is inactive, so it isn't ready to evaluate data. Check your alarm model information and update the alarm model.
-
`FAILED` - You couldn't create or update the alarm model. Check your alarm model information and try again.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
Contains information about the status of the alarm model.
2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 |
# File 'lib/aws-sdk-iotevents/types.rb', line 2252 class DescribeAlarmModelResponse < Struct.new( :creation_time, :alarm_model_arn, :alarm_model_version, :last_update_time, :status, :status_message, :alarm_model_name, :alarm_model_description, :role_arn, :key, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |