Class: Aws::IoTEvents::Types::DetectorModelVersionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotevents/types.rb

Overview

Information about the detector model version.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

The time the detector model version was created.

Returns:

  • (Time)


1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/aws-sdk-iotevents/types.rb', line 1426

class DetectorModelVersionSummary < Struct.new(
  :detector_model_name,
  :detector_model_version,
  :detector_model_arn,
  :role_arn,
  :creation_time,
  :last_update_time,
  :status,
  :evaluation_method)
  SENSITIVE = []
  include Aws::Structure
end

#detector_model_arn ⇒ String

The ARN of the detector model version.

Returns:

  • (String)


1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/aws-sdk-iotevents/types.rb', line 1426

class DetectorModelVersionSummary < Struct.new(
  :detector_model_name,
  :detector_model_version,
  :detector_model_arn,
  :role_arn,
  :creation_time,
  :last_update_time,
  :status,
  :evaluation_method)
  SENSITIVE = []
  include Aws::Structure
end

#detector_model_name ⇒ String

The name of the detector model.

Returns:

  • (String)


1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/aws-sdk-iotevents/types.rb', line 1426

class DetectorModelVersionSummary < Struct.new(
  :detector_model_name,
  :detector_model_version,
  :detector_model_arn,
  :role_arn,
  :creation_time,
  :last_update_time,
  :status,
  :evaluation_method)
  SENSITIVE = []
  include Aws::Structure
end

#detector_model_version ⇒ String

The ID of the detector model version.

Returns:

  • (String)


1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/aws-sdk-iotevents/types.rb', line 1426

class DetectorModelVersionSummary < Struct.new(
  :detector_model_name,
  :detector_model_version,
  :detector_model_arn,
  :role_arn,
  :creation_time,
  :last_update_time,
  :status,
  :evaluation_method)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_method ⇒ String

Information about the order in which events are evaluated and how actions are executed.

Returns:

  • (String)


1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/aws-sdk-iotevents/types.rb', line 1426

class DetectorModelVersionSummary < Struct.new(
  :detector_model_name,
  :detector_model_version,
  :detector_model_arn,
  :role_arn,
  :creation_time,
  :last_update_time,
  :status,
  :evaluation_method)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_time ⇒ Time

The last time the detector model version was updated.

Returns:

  • (Time)


1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/aws-sdk-iotevents/types.rb', line 1426

class DetectorModelVersionSummary < Struct.new(
  :detector_model_name,
  :detector_model_version,
  :detector_model_arn,
  :role_arn,
  :creation_time,
  :last_update_time,
  :status,
  :evaluation_method)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The ARN of the role that grants the detector model permission to perform its tasks.

Returns:

  • (String)


1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/aws-sdk-iotevents/types.rb', line 1426

class DetectorModelVersionSummary < Struct.new(
  :detector_model_name,
  :detector_model_version,
  :detector_model_arn,
  :role_arn,
  :creation_time,
  :last_update_time,
  :status,
  :evaluation_method)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the detector model version.

Returns:

  • (String)


1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
# File 'lib/aws-sdk-iotevents/types.rb', line 1426

class DetectorModelVersionSummary < Struct.new(
  :detector_model_name,
  :detector_model_version,
  :detector_model_arn,
  :role_arn,
  :creation_time,
  :last_update_time,
  :status,
  :evaluation_method)
  SENSITIVE = []
  include Aws::Structure
end