Class: Aws::IoTEvents::Types::EmailConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotevents/types.rb

Overview

Note:

When making an API call, you may pass EmailConfiguration data as a hash:

{
  from: "FromEmail", # required
  content: {
    subject: "EmailSubject",
    additional_message: "NotificationAdditionalMessage",
  },
  recipients: { # required
    to: [
      {
        sso_identity: {
          identity_store_id: "IdentityStoreId", # required
          user_id: "SSOReferenceId",
        },
      },
    ],
  },
}

Contains the configuration information of email notifications.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentTypes::EmailContent

Contains the subject and message of an email.

Returns:



3355
3356
3357
3358
3359
3360
3361
# File 'lib/aws-sdk-iotevents/types.rb', line 3355

class EmailConfiguration < Struct.new(
  :from,
  :content,
  :recipients)
  SENSITIVE = []
  include Aws::Structure
end

#fromString

The email address that sends emails.

If you use the AWS IoT Events managed AWS Lambda function to manage your emails, you must [verify the email address that sends emails in Amazon SES].

[1]: docs.aws.amazon.com/ses/latest/DeveloperGuide/verify-email-addresses.html

Returns:

  • (String)


3355
3356
3357
3358
3359
3360
3361
# File 'lib/aws-sdk-iotevents/types.rb', line 3355

class EmailConfiguration < Struct.new(
  :from,
  :content,
  :recipients)
  SENSITIVE = []
  include Aws::Structure
end

#recipientsTypes::EmailRecipients

Contains the information of one or more recipients who receive the emails.

You must [add the users that receive emails to your AWS SSO store].

[1]: docs.aws.amazon.com/singlesignon/latest/userguide/addusers.html



3355
3356
3357
3358
3359
3360
3361
# File 'lib/aws-sdk-iotevents/types.rb', line 3355

class EmailConfiguration < Struct.new(
  :from,
  :content,
  :recipients)
  SENSITIVE = []
  include Aws::Structure
end