Class: Aws::IoTEvents::Types::SMSConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEvents::Types::SMSConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotevents/types.rb
Overview
Note:
When making an API call, you may pass SMSConfiguration data as a hash:
{
sender_id: "SMSSenderId",
additional_message: "NotificationAdditionalMessage",
recipients: [ # required
{
sso_identity: {
identity_store_id: "IdentityStoreId", # required
user_id: "SSOReferenceId",
},
},
],
}
Contains the configuration information of SMS notifications.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_message ⇒ String
The message that you want to send.
-
#recipients ⇒ Array<Types::RecipientDetail>
Specifies one or more recipients who receive the message.
-
#sender_id ⇒ String
The sender ID.
Instance Attribute Details
#additional_message ⇒ String
The message that you want to send. The message can be up to 200 characters.
5271 5272 5273 5274 5275 5276 5277 |
# File 'lib/aws-sdk-iotevents/types.rb', line 5271 class SMSConfiguration < Struct.new( :sender_id, :additional_message, :recipients) SENSITIVE = [] include Aws::Structure end |
#recipients ⇒ Array<Types::RecipientDetail>
Specifies one or more recipients who receive the message.
You must [add the users that receive SMS messages to your AWS SSO store].
[1]: docs.aws.amazon.com/singlesignon/latest/userguide/addusers.html
5271 5272 5273 5274 5275 5276 5277 |
# File 'lib/aws-sdk-iotevents/types.rb', line 5271 class SMSConfiguration < Struct.new( :sender_id, :additional_message, :recipients) SENSITIVE = [] include Aws::Structure end |
#sender_id ⇒ String
The sender ID.
5271 5272 5273 5274 5275 5276 5277 |
# File 'lib/aws-sdk-iotevents/types.rb', line 5271 class SMSConfiguration < Struct.new( :sender_id, :additional_message, :recipients) SENSITIVE = [] include Aws::Structure end |