Class: Aws::IoTEvents::Types::SetTimerAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotevents/types.rb

Overview

Information needed to set the timer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#duration_expression ⇒ String

The duration of the timer, in seconds. You can use a string expression that includes numbers, variables ($variable.<variable-name>), and input values ($input.<input-name>.<path-to-datum>) as the duration. The range of the duration is 1-31622400 seconds. To ensure accuracy, the minimum duration is 60 seconds. The evaluated result of the duration is rounded down to the nearest whole number.



2766
2767
2768
2769
2770
2771
2772
# File 'lib/aws-sdk-iotevents/types.rb', line 2766

class SetTimerAction < Struct.new(
  :timer_name,
  :seconds,
  :duration_expression)
  SENSITIVE = []
  include Aws::Structure
end

#seconds ⇒ Integer

The number of seconds until the timer expires. The minimum value is 60 seconds to ensure accuracy. The maximum value is 31622400 seconds.



2766
2767
2768
2769
2770
2771
2772
# File 'lib/aws-sdk-iotevents/types.rb', line 2766

class SetTimerAction < Struct.new(
  :timer_name,
  :seconds,
  :duration_expression)
  SENSITIVE = []
  include Aws::Structure
end

#timer_name ⇒ String

The name of the timer.



2766
2767
2768
2769
2770
2771
2772
# File 'lib/aws-sdk-iotevents/types.rb', line 2766

class SetTimerAction < Struct.new(
  :timer_name,
  :seconds,
  :duration_expression)
  SENSITIVE = []
  include Aws::Structure
end