Class: Aws::IoTEvents::Types::SimpleRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEvents::Types::SimpleRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotevents/types.rb
Overview
Note:
When making an API call, you may pass SimpleRule data as a hash:
{
input_property: "InputProperty", # required
comparison_operator: "GREATER", # required, accepts GREATER, GREATER_OR_EQUAL, LESS, LESS_OR_EQUAL, EQUAL, NOT_EQUAL
threshold: "Threshold", # required
}
A rule that compares an input property value to a threshold value with a comparison operator.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comparison_operator ⇒ String
The comparison operator.
-
#input_property ⇒ String
The value on the left side of the comparison operator.
-
#threshold ⇒ String
The value on the right side of the comparison operator.
Instance Attribute Details
#comparison_operator ⇒ String
The comparison operator.
5440 5441 5442 5443 5444 5445 5446 |
# File 'lib/aws-sdk-iotevents/types.rb', line 5440 class SimpleRule < Struct.new( :input_property, :comparison_operator, :threshold) SENSITIVE = [] include Aws::Structure end |
#input_property ⇒ String
The value on the left side of the comparison operator. You can specify an AWS IoT Events input attribute as an input property.
5440 5441 5442 5443 5444 5445 5446 |
# File 'lib/aws-sdk-iotevents/types.rb', line 5440 class SimpleRule < Struct.new( :input_property, :comparison_operator, :threshold) SENSITIVE = [] include Aws::Structure end |
#threshold ⇒ String
The value on the right side of the comparison operator. You can enter a number or specify an AWS IoT Events input attribute.
5440 5441 5442 5443 5444 5445 5446 |
# File 'lib/aws-sdk-iotevents/types.rb', line 5440 class SimpleRule < Struct.new( :input_property, :comparison_operator, :threshold) SENSITIVE = [] include Aws::Structure end |