Class: Aws::IoTEvents::Types::UpdateAlarmModelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTEvents::Types::UpdateAlarmModelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotevents/types.rb
Overview
When making an API call, you may pass UpdateAlarmModelRequest data as a hash:
{
alarm_model_name: "AlarmModelName", # required
alarm_model_description: "AlarmModelDescription",
role_arn: "AmazonResourceName", # required
severity: 1,
alarm_rule: { # required
simple_rule: {
input_property: "InputProperty", # required
comparison_operator: "GREATER", # required, accepts GREATER, GREATER_OR_EQUAL, LESS, LESS_OR_EQUAL, EQUAL, NOT_EQUAL
threshold: "Threshold", # required
},
},
alarm_notification: {
notification_actions: [
{
action: { # required
lambda_action: {
function_arn: "AmazonResourceName", # required
payload: {
content_expression: "ContentExpression", # required
type: "STRING", # required, accepts STRING, JSON
},
},
},
sms_configurations: [
{
sender_id: "SMSSenderId",
additional_message: "NotificationAdditionalMessage",
recipients: [ # required
{
sso_identity: {
identity_store_id: "IdentityStoreId", # required
user_id: "SSOReferenceId",
},
},
],
},
],
email_configurations: [
{
from: "FromEmail", # required
content: {
subject: "EmailSubject",
additional_message: "NotificationAdditionalMessage",
},
recipients: { # required
to: [
{
sso_identity: {
identity_store_id: "IdentityStoreId", # required
user_id: "SSOReferenceId",
},
},
],
},
},
],
},
],
},
alarm_event_actions: {
alarm_actions: [
{
sns: {
target_arn: "AmazonResourceName", # required
payload: {
content_expression: "ContentExpression", # required
type: "STRING", # required, accepts STRING, JSON
},
},
iot_topic_publish: {
mqtt_topic: "MQTTTopic", # required
payload: {
content_expression: "ContentExpression", # required
type: "STRING", # required, accepts STRING, JSON
},
},
lambda: {
function_arn: "AmazonResourceName", # required
payload: {
content_expression: "ContentExpression", # required
type: "STRING", # required, accepts STRING, JSON
},
},
iot_events: {
input_name: "InputName", # required
payload: {
content_expression: "ContentExpression", # required
type: "STRING", # required, accepts STRING, JSON
},
},
sqs: {
queue_url: "QueueUrl", # required
use_base_64: false,
payload: {
content_expression: "ContentExpression", # required
type: "STRING", # required, accepts STRING, JSON
},
},
firehose: {
delivery_stream_name: "DeliveryStreamName", # required
separator: "FirehoseSeparator",
payload: {
content_expression: "ContentExpression", # required
type: "STRING", # required, accepts STRING, JSON
},
},
dynamo_db: {
hash_key_type: "DynamoKeyType",
hash_key_field: "DynamoKeyField", # required
hash_key_value: "DynamoKeyValue", # required
range_key_type: "DynamoKeyType",
range_key_field: "DynamoKeyField",
range_key_value: "DynamoKeyValue",
operation: "DynamoOperation",
payload_field: "DynamoKeyField",
table_name: "DynamoTableName", # required
payload: {
content_expression: "ContentExpression", # required
type: "STRING", # required, accepts STRING, JSON
},
},
dynamo_d_bv_2: {
table_name: "DynamoTableName", # required
payload: {
content_expression: "ContentExpression", # required
type: "STRING", # required, accepts STRING, JSON
},
},
iot_site_wise: {
entry_id: "AssetPropertyEntryId",
asset_id: "AssetId",
property_id: "AssetPropertyId",
property_alias: "AssetPropertyAlias",
property_value: {
value: {
string_value: "AssetPropertyStringValue",
integer_value: "AssetPropertyIntegerValue",
double_value: "AssetPropertyDoubleValue",
boolean_value: "AssetPropertyBooleanValue",
},
timestamp: {
time_in_seconds: "AssetPropertyTimeInSeconds", # required
offset_in_nanos: "AssetPropertyOffsetInNanos",
},
quality: "AssetPropertyQuality",
},
},
},
],
},
alarm_capabilities: {
initialization_configuration: {
disabled_on_initialization: false, # required
},
acknowledge_flow: {
enabled: false, # required
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alarm_capabilities ⇒ Types::AlarmCapabilities
Contains the configuration information of alarm state changes.
-
#alarm_event_actions ⇒ Types::AlarmEventActions
Contains information about one or more alarm actions.
-
#alarm_model_description ⇒ String
The description of the alarm model.
-
#alarm_model_name ⇒ String
The name of the alarm model.
-
#alarm_notification ⇒ Types::AlarmNotification
Contains information about one or more notification actions.
-
#alarm_rule ⇒ Types::AlarmRule
Defines when your alarm is invoked.
-
#role_arn ⇒ String
The ARN of the IAM role that allows the alarm to perform actions and access AWS resources.
-
#severity ⇒ Integer
A non-negative integer that reflects the severity level of the alarm.
Instance Attribute Details
#alarm_capabilities ⇒ Types::AlarmCapabilities
Contains the configuration information of alarm state changes.
6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-iotevents/types.rb', line 6899 class UpdateAlarmModelRequest < Struct.new( :alarm_model_name, :alarm_model_description, :role_arn, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_event_actions ⇒ Types::AlarmEventActions
Contains information about one or more alarm actions.
6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-iotevents/types.rb', line 6899 class UpdateAlarmModelRequest < Struct.new( :alarm_model_name, :alarm_model_description, :role_arn, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_model_description ⇒ String
The description of the alarm model.
6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-iotevents/types.rb', line 6899 class UpdateAlarmModelRequest < Struct.new( :alarm_model_name, :alarm_model_description, :role_arn, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_model_name ⇒ String
The name of the alarm model.
6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-iotevents/types.rb', line 6899 class UpdateAlarmModelRequest < Struct.new( :alarm_model_name, :alarm_model_description, :role_arn, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_notification ⇒ Types::AlarmNotification
Contains information about one or more notification actions.
6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-iotevents/types.rb', line 6899 class UpdateAlarmModelRequest < Struct.new( :alarm_model_name, :alarm_model_description, :role_arn, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#alarm_rule ⇒ Types::AlarmRule
Defines when your alarm is invoked.
6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-iotevents/types.rb', line 6899 class UpdateAlarmModelRequest < Struct.new( :alarm_model_name, :alarm_model_description, :role_arn, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that allows the alarm to perform actions and access AWS resources. For more information, see [Amazon Resource Names (ARNs)] in the *AWS General Reference*.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html
6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-iotevents/types.rb', line 6899 class UpdateAlarmModelRequest < Struct.new( :alarm_model_name, :alarm_model_description, :role_arn, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ Integer
A non-negative integer that reflects the severity level of the alarm.
6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-iotevents/types.rb', line 6899 class UpdateAlarmModelRequest < Struct.new( :alarm_model_name, :alarm_model_description, :role_arn, :severity, :alarm_rule, :alarm_notification, :alarm_event_actions, :alarm_capabilities) SENSITIVE = [] include Aws::Structure end |